
(defpackage "WAM-CL" (:nicknames "SB-SYS" "SB-INT" "CS-CL"))

(defpackage "SYSTEM" (:nicknames "SYS"))
(defpackage "COMMON-LISP" (:nicknames "CL" "LISP")(:uses "SYSTEM"))
;; (defpackage "COMMON-LISP-USER" (:nicknames "U" "USER" "CL-USER") (:uses "COMMON-LISP"))
(defvar *lisp-file-type* "lisp") 
(defvar *default-pathname-defaults* #P"")

(defun all-cdr (lists)
  (when lists (cons (cdar lists) (all-cdr (cdr lists)))))

(defun mapcar (function &rest lists)
    (let ((result nil)
	  (end nil))
      (tagbody
       start
	 (when (all-end lists) (return-from mapcar result))
	 (let ((cons (cons (apply function (all-car lists)) nil)))
	   (setf end (if end (setf (cdr end) cons) (setf result cons))))
	 (setf lists (all-cdr lists))
	 (go start))))


(defvar *setf-expanders*  (make-hash-table))


(defun map-to-gensyms (list)
  (mapcar (lambda (x) (gensym)) list))

(defmacro with-gensyms (syms &body body)
  `(let ,(mapcar (lambda (sym) `(,sym ',(gensym))) syms)
     ,@body))

(defun cl:string (x)
  (cond
    ((stringp x)	x)
    ((symbolp x)	(symbol-name x))
    (t			(error "type error"))))


(defun string (x)
  (cond
    ((stringp x)	x)
    ((symbolp x)	(symbol-name x))
    (t			(error "type error"))))



(defun make-macro-el-function (name lambda-list body)
  (with-gensyms (fvar evar)
    (let ((e (memq '&environment lambda-list))
	  (form fvar))
      (when e
	(when (null (cdr e))
	  (error 'program-error))
	(setq evar (second e))
	(let ((x lambda-list))
	  (while x
	    (when (eq (cadr x) '&environment)
	      (setf (cdr x) (cdddr x)))
	    (setq x (cdr x)))))
      (if (eq (first lambda-list) '&whole)
	  (unless (= (length lambda-list) 2)
	    (push (gensym) (cddr lambda-list)))
	  (setq form `(cdr ,fvar)))
      (unless (null lambda-list)
	(setq body `((destructuring-bind ,lambda-list ,form ,@body))))
      `(lambda (,fvar ,evar) ,@body))))

(defmacro define-setf-expander (access-fn lambda-list &body body)
  `(eval-when (:compile-toplevel :load-toplevel :execute)
     (setf (gethash ',access-fn *setf-expanders*)
           ,(make-macro-el-function access-fn lambda-list body))
     ',access-fn))


(defmacro define-modify-macro (name lambda-list fn &optional documentation)
  (with-gensyms (place env temps values variables setter getter)
    `(defmacro ,name (,place ,@lambda-list &environment ,env)
       ,documentation
       (multiple-value-bind (,temps ,values ,variables ,setter ,getter)
	   (get-setf-expansion ,place ,env)
	 (backquote
	   (let*   ((comma-at (mapcar (function list) ,temps ,values))
		  ((comma (first ,variables))
;; todo: only params from lambda-list		   
		   (,fn (comma ,getter) ,@lambda-list)))
	     (comma ,setter)))))))


;;(prolog-trace)

(defmacro defsetf (access-fn &rest args)
  (case (length args)
    (0	(error "syntax error"))
    (1	(cl-short-form-defsetf access-fn (first args)))
    (2	(cond
	  ((stringp (second args))
	   (cl-short-form-defsetf access-fn (first args) (second args)))
	  ((listp (second args))
	   (apply #'cl-long-form-defsetf access-fn args))
	  (t
	   (type-error (second args) '(or string list)))))
    (t	(apply #'cl-long-form-defsetf access-fn args))))


;;(prolog-trace)

(defun short-form-defsetf (access-fn update-fn)
  `(define-setf-expander ,access-fn (&rest args)
     (let ((var (gensym))
	   (temps (map-to-gensyms args)))
       (cl:values temps
		  args
		  (list var)
		  (append '(,update-fn) temps (list var))
		  (list* ',access-fn temps)))))

(defun long-form-defsetf (access-fn lambda-list variables &body body)
  (let ((args (remove-if (lambda (x) (memq x '(&optional &rest &key)))
			 lambda-list)))
    `(define-setf-expander ,access-fn ,lambda-list
       (let*   ((var (gensym))
	     (temps (map-to-gensyms ',args))
	     (,(first variables) var))
	 (cl:values temps
		    (list ,@args)
		    (list var)
		    (apply (lambda ,lambda-list ,@body) temps)
		    (cons ',access-fn temps))))))


(defun cl-short-form-defsetf (access-fn update-fn &optional doc)
  (with-gensyms (args var temps)
    `(define-setf-expander ,access-fn (&rest ,args)
      (let ((,var (gensym))
	    (,temps (map-to-gensyms ,args)))
	(values ,temps
		,args
		(list ,var)
		(backquote (,update-fn (comma-at ,temps) (comma ,var)))
		(backquote (,access-fn (comma-at ,temps))))))))

(defun cl-long-form-defsetf (access-fn lambda-list variables &body body)
  (let ((args (remove-if (lambda (x) (memq x lambda-list-keywords))
			 lambda-list)))
    (with-gensyms (var temps)
      `(define-setf-expander ,access-fn ,lambda-list
	(let*   ((,var (gensym))
	       (,temps (map-to-gensyms (quote ,args)))
	       (,(first variables) ,var))
	  (values ,temps
		  (list ,@args)
		  (list ,var)
		  (apply (lambda ,lambda-list ,@body) ,temps)
		  (backquote (,access-fn (comma-at ,temps)))))))))


(define-setf-expander values (&rest forms)
  (let ((temporaries nil)
	(values nil)
	(vars nil)
	(setters nil)
	(getters nil))
    (dolist (form forms)
      (multiple-value-bind (temps vals variables setter getter)
	  (get-setf-expansion form nil) ;todo: env
	(setq temporaries (append temporaries temps))
	(setq values (append values vals))
	(push (first variables) vars)
	(push setter setters)
	(push getter getters)))
    (cl:values temporaries
	       values
	       (nreverse vars)
	       `(progn ,@(nreverse setters))
	       `(values ,@(nreverse getters)))))

;; Test macro
(defmacro is (eqf expected actual)
  (let ((a (gensym "a")) (b (gensym "b")))
    `(let ((,a ,expected) (,b ,actual))
       (if (not (,eqf ,a ,b))
         (progn
           (format t "FAILED: when matching ~a and ~a~%" ',expected ',actual)
           (quit 1))
         (format t "OK: ~a is ~a to ~a~%" ',expected ',eqf ',actual)))))

(write-line "Running smoke test!")

(is eq 1 1)
(is equal (list 1 'a 'b) (cons 1 '(a b)))

(is eq 2 (if nil 1 2))

(is eq t (keywordp :k))

(is eq 10 (if t 10 20))

(is eq t (stringp "abc"))
(is equal (subseq "abc" 1) "bc")

(is eq 1 (if t 1 2))
(is eq 2 (if nil 1 2))

(defun accum (r) (if (= 0 r) (list 0) (cons r (accum (- r 1)))))
(is equal (list 4 3 2 1 0) (accum 4))

(defmacro defwrap (name) `(defun ,name () 1))
(defwrap foo)
(is eq 1 (foo))
(is equal (macroexpand-1 '(defwrap foo)) '(defun foo nil 1))

(write-line "PASSED")

(DEFPARAMETER WAM-CL::*TTY*  ())
;;(DEFPARAMETER WAM-CL::*STDOUT*  ())
;;(DEFPARAMETER WAM-CL::*STDIN*  ())
;;(DEFINE-SYMBOL-MACRO WAM-CL::*STDERR*  ())



(DEFPARAMETER CL::*QUERY-IO*  (MAKE-SYNONYM-STREAM 'CL::*TERMINAL-IO*))
(DEFPARAMETER CL::*READTABLE*  (MAKE-READ-TABLE))
(DEFPARAMETER CL::*STANDARD-INPUT* (MAKE-SYNONYM-STREAM 'WAM-CL::*STDIN* ))
(DEFPARAMETER CL::*STANDARD-OUTPUT*  (MAKE-SYNONYM-STREAM 'WAM-CL::*STDOUT* ))
(DEFPARAMETER CL::*TRACE-OUTPUT*  (MAKE-SYNONYM-STREAM 'WAM-CL::*STDOUT* ))
(DEFPARAMETER CL::*TERMINAL-IO*  (MAKE-SYNONYM-STREAM 'WAM-CL::*TTY*))
(DEFPARAMETER CL::*RANDOM-STATE* #S(CL::RANDOM-STATE #*1011011101101001011011110100000110001010000110011100000010110111))
(DEFPARAMETER CL::*PACKAGE* #.(FIND-PACKAGE "COMMON-LISP-USER"))

;;(prolog-trace)

(DEFPARAMETER CL::*DEBUG-IO*  (MAKE-SYNONYM-STREAM 'CL::*TERMINAL-IO*))
(DEFPARAMETER CL::*ERROR-OUTPUT*  (MAKE-SYNONYM-STREAM 'WAM-CL::*STDERR* ))
(DEFPARAMETER SYS::*HT* #S(CL::HASH-TABLE :TEST CL::EQUALP  ))
(DEFPARAMETER SYS::*LOGICAL-PATHNAME-TRANSLATIONS* #S(CL::HASH-TABLE :TEST CL::EQUALP   
  ("SYS" . ((#S(CL::LOGICAL-PATHNAME :HOST "SYS" :DEVICE :UNSPECIFIC :DIRECTORY (:RELATIVE) :NAME :WILD :TYPE "LISP" :VERSION ()) "*.lisp")
	    (#S(CL::LOGICAL-PATHNAME :HOST "SYS" :DEVICE :UNSPECIFIC :DIRECTORY (:RELATIVE) :NAME :WILD :TYPE () :VERSION ()) "*")
	    (#S(CL::LOGICAL-PATHNAME :HOST "SYS" :DEVICE :UNSPECIFIC :DIRECTORY (:ABSOLUTE) :NAME :WILD :TYPE () :VERSION ()) "/*")
	    )))
	    )
(DEFCONSTANT SYS::*KEYWORD-PACKAGE* #.(FIND-PACKAGE "KEYWORD"))
(DEFCONSTANT SYS::*LISP-PACKAGE* #.(FIND-PACKAGE "COMMON-LISP"))
(DEFCONSTANT SYS::*OPTIMIZE* #S(CL::HASH-TABLE :TEST EXT::STABLEHASH-EQ))
(DEFCONSTANT CLOS::EMPTY-HT #S(CL::HASH-TABLE :TEST EXT::FASTHASH-EQ :WARN-IF-NEEDS-REHASH-AFTER-GC T))



(DEFCONSTANT CL::ARRAY-DIMENSION-LIMIT 4611686018427387901)
(DEFCONSTANT CL::ARRAY-RANK-LIMIT 65529)
(DEFCONSTANT CL::ARRAY-TOTAL-SIZE-LIMIT 4611686018427387901)

(DEFPARAMETER CL::*GENSYM-COUNTER* 0)
(DEFCONSTANT CL::BOOLE-1 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-2 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-AND (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-ANDC1 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-ANDC2 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-C1 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-C2 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-CLR (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-EQV (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-IOR (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-NAND (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-NOR (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-ORC1 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-ORC2 (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-SET (incf *gensym-counter*))
(DEFCONSTANT CL::BOOLE-XOR (incf *gensym-counter*))

(DEFPARAMETER CL::*DEFAULT-PATHNAME-DEFAULTS* #-CLISP #P"" #+CLISP #S(CL::PATHNAME :HOST () :DEVICE () :DIRECTORY () :NAME () :TYPE () :VERSION ()))
(DEFPARAMETER CL::*FEATURES* '(:64-BIT :64-BIT-REGISTERS :ALIEN-CALLBACKS :ANSI-CL :ASH-RIGHT-VOPS :C-STACK-IS-CONTROL-STACK :COMMON-LISP :COMPARE-AND-SWAP-VOPS :COMPLEX-FLOAT-VOPS :CYCLE-COUNTER :ELF :FLOAT-EQL-VOPS :FP-AND-PC-STANDARD-SAVE :GENCGC :IEEE-FLOATING-POINT :INLINE-CONSTANTS :INTEGER-EQL-VOP :INTERLEAVED-RAW-SLOTS :LARGEFILE :LINKAGE-TABLE :LINUX :LITTLE-ENDIAN :MEMORY-BARRIER-VOPS :MULTIPLY-HIGH-VOPS :OS-PROVIDES-BLKSIZE-T :OS-PROVIDES-DLADDR :OS-PROVIDES-DLOPEN :OS-PROVIDES-GETPROTOBY-R :OS-PROVIDES-POLL :OS-PROVIDES-PUTWC :OS-PROVIDES-SUSECONDS-T :PACKAGE-LOCAL-NICKNAMES :PRECISE-ARG-COUNT-ERROR :RAW-INSTANCE-INIT-VOPS :SB-AFTER-XC-CORE :SB-CORE-COMPRESSION :SB-DOC :SB-EVAL :SB-FUTEX :SB-LDB :SB-PACKAGE-LOCKS :SB-SIMD-PACK :SB-SOURCE-LOCATIONS :SB-TEST :SB-THREAD :SB-UNICODE :SB-XREF-FOR-INTERNALS :SBCL :STACK-ALLOCATABLE-CLOSURES :STACK-ALLOCATABLE-FIXED-OBJECTS :STACK-ALLOCATABLE-LISTS :STACK-ALLOCATABLE-VECTORS :STACK-GROWS-DOWNWARD-NOT-UPWARD :SYMBOL-INFO-VOPS :UNIX :UNWIND-TO-FRAME-AND-CALL-VOP :X86-64))
(DEFPARAMETER CL::*FEATURES* (append *FEATURES* '(:READLINE :REGEXP :SYSCALLS :I18N :LOOP :COMPILER :CLOS :MOP :CLISP :ANSI-CL :COMMON-LISP :LISP=CL :INTERPRETER :SOCKETS :GENERIC-STREAMS :LOGICAL-PATHNAMES :SCREEN :FFI :GETTEXT :UNICODE :BASE-CHAR=CHARACTER :WORD-SIZE=64 :PC386 :UNIX)))
(DEFPARAMETER CL::*FEATURES* (append *FEATURES* '(:X86-64 :JAVA-1.8 :UNIX :LINUX :WAM-ARMEDBEAR :WAM-CL :COMMON-LISP :ANSI-CL :CDR6 :MOP :PACKAGE-LOCAL-NICKNAMES)))
(DEFPARAMETER CL::*LOAD-PATHNAME*  ())
(DEFPARAMETER CL::*LOAD-PRINT*  ())
(DEFPARAMETER CL::*LOAD-TRUENAME*  ())
(DEFPARAMETER CL::*LOAD-VERBOSE* T)
(DEFPARAMETER CL::*MACROEXPAND-HOOK* 'CL::FUNCALL)
(DEFPARAMETER CL::*MODULES* '("INSPECT" "FORMAT" "PRINT-OBJECT" "CLOS" "MOP" "DELETE" "COLLECT" "PPRINT-DISPATCH" "PPRINT" "PRINT" "EXTENSIBLE-SEQUENCES-BASE"))
(DEFPARAMETER CL::*MODULES* '("readline" "regexp" "syscalls" "i18n"))
(DEFPARAMETER CL::*MODULES*  ())
(DEFPARAMETER CL::*PRINT-ARRAY* T)
(DEFPARAMETER CL::*PRINT-BASE* 10)
(DEFPARAMETER CL::*PRINT-CASE* :UPCASE)
(DEFCONSTANT SYS::FORMAT-CARDINAL-ONES #(() "one" "two" "three" "four" "five" "six" "seven" "eight" "nine" "ten" "eleven" "twelve" "thirteen" "fourteen" "fifteen" "sixteen" "seventeen" "eighteen" "nineteen"))
(DEFCONSTANT SYS::FORMAT-CARDINAL-TENS #(() () "twenty" "thirty" "forty" "fifty" "sixty" "seventy" "eighty" "ninety"))
(DEFCONSTANT SYS::FORMAT-ORDINAL-ONES #(() "first" "second" "third" "fourth" "fifth" "sixth" "seventh" "eighth" "ninth" "tenth" "eleventh" "twelfth" "thirteenth" "fourteenth" "fifteenth" "sixteenth" "seventeenth" "eighteenth" "nineteenth"))

(DEFCONSTANT CL::CALL-ARGUMENTS-LIMIT 4611686018427387903)


(DEFCONSTANT CL::CHAR-CODE-LIMIT 65536)
(DEFCONSTANT CL::INTERNAL-TIME-UNITS-PER-SECOND 1000)
(DEFCONSTANT CL::INTERNAL-TIME-UNITS-PER-SECOND 1000000)
(DEFCONSTANT CL::LAMBDA-LIST-KEYWORDS '(SYS::&MORE CL::&ALLOW-OTHER-KEYS CL::&AUX CL::&BODY CL::&ENVIRONMENT CL::&KEY CL::&OPTIONAL CL::&REST CL::&WHOLE))
(DEFCONSTANT CL::LAMBDA-PARAMETERS-LIMIT 4611686018427387903)
(DEFCONSTANT CL::MULTIPLE-VALUES-LIMIT 128)
(DEFCONSTANT CL::MULTIPLE-VALUES-LIMIT 32)
(DEFCONSTANT CL::MULTIPLE-VALUES-LIMIT 4611686018427387903)
(DEFCONSTANT CL::NIL ())
(DEFCONSTANT LISP:T T)
(DEFCONSTANT CLOS::*<BUILT-IN-CLASS>-INSTANCE-SIZE* 17)
(DEFCONSTANT CLOS::*<BUILT-IN-CLASS>-PROTOTYPE-LOCATION* 16)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-ALL-SUPERCLASSES-LOCATION* 6)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-DEFAULT-INITARGS-LOCATION* 12)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-DIRECT-DEFAULT-INITARGS-LOCATION* 11)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-DIRECT-SLOTS-LOCATION* 8)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-DIRECT-SUPERCLASSES-LOCATION* 5)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-DOCUMENTATION-LOCATION* 13)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-INITIALIZED-LOCATION* 15)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-LISTENERS-LOCATION* 14)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-PRECEDENCE-LIST-LOCATION* 7)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-SLOT-LOCATION-TABLE-LOCATION* 10)
(DEFCONSTANT CLOS::*<DEFINED-CLASS>-SLOTS-LOCATION* 9)
(DEFCONSTANT CLOS::*<DIRECT-SLOT-DEFINITION>-READERS-LOCATION* 7)
(DEFCONSTANT CLOS::*<DIRECT-SLOT-DEFINITION>-WRITERS-LOCATION* 8)
(DEFCONSTANT CLOS::*<EFFECTIVE-SLOT-DEFINITION>-EFM-SBUC-LOCATION* 10)
(DEFCONSTANT CLOS::*<EFFECTIVE-SLOT-DEFINITION>-EFM-SMUC-LOCATION* 11)
(DEFCONSTANT CLOS::*<EFFECTIVE-SLOT-DEFINITION>-EFM-SSVUC-LOCATION* 9)
(DEFCONSTANT CLOS::*<EFFECTIVE-SLOT-DEFINITION>-EFM-SVUC-LOCATION* 8)
(DEFCONSTANT CLOS::*<EFFECTIVE-SLOT-DEFINITION>-LOCATION-LOCATION* 7)
(DEFCONSTANT CLOS::*<EQL-SPECIALIZER>-INSTANCE-SIZE* 4)
(DEFCONSTANT CLOS::*<EQL-SPECIALIZER>-SINGLETON-LOCATION* 3)
(DEFCONSTANT CLOS::*<FUNCALLABLE-STANDARD-CLASS>-INSTANCE-SIZE* 28)
(DEFCONSTANT CLOS::*<FUNCALLABLE-STANDARD-CLASS>-VALID-INITIALIZATION-KEYWORDS* '(:NAME :DIRECT-SUPERCLASSES :DIRECT-SLOTS :DIRECT-DEFAULT-INITARGS :DOCUMENTATION :GENERIC-ACCESSORS :FIXED-SLOT-LOCATIONS))
(DEFCONSTANT CLOS::*<POTENTIAL-CLASS>-CLASSNAME-LOCATION* 3)
(DEFCONSTANT CLOS::*<POTENTIAL-CLASS>-DIRECT-SUBCLASSES-LOCATION* 4)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-CURRENT-VERSION-LOCATION* 21)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-DIRECT-INSTANCE-SPECIALIZERS-LOCATION* 25)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-FINALIZED-DIRECT-SUBCLASSES-LOCATION* 26)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-FIXED-SLOT-LOCATIONS-LOCATION* 23)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-FUNCALLABLEP-LOCATION* 22)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-INSTANTIATED-LOCATION* 24)
(DEFCONSTANT CLOS::*<SEMI-STANDARD-CLASS>-PROTOTYPE-LOCATION* 27)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-ALLOCATION-LOCATION* 4)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-INHERITABLE-DOC-LOCATION* 6)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-INHERITABLE-INITER-LOCATION* 5)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-INITARGS-LOCATION* 2)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-NAME-LOCATION* 1)
(DEFCONSTANT CLOS::*<SLOT-DEFINITION>-TYPE-LOCATION* 3)
(DEFCONSTANT CLOS::*<SLOTTED-CLASS>-DIRECT-ACCESSORS-LOCATION* 18)
(DEFCONSTANT CLOS::*<SLOTTED-CLASS>-GENERIC-ACCESSORS-LOCATION* 17)
(DEFCONSTANT CLOS::*<SLOTTED-CLASS>-INSTANCE-SIZE-LOCATION* 20)
(DEFCONSTANT CLOS::*<SLOTTED-CLASS>-SUBCLASS-OF-STABLEHASH-P-LOCATION* 16)
(DEFCONSTANT CLOS::*<SLOTTED-CLASS>-VALID-INITARGS-FROM-SLOTS-LOCATION* 19)
(DEFCONSTANT CLOS::*<SPECIALIZER>-DIRECT-METHODS-LOCATION* 2)
(DEFCONSTANT CLOS::*<STANDARD-CLASS>-DEFAULT-INITARGS* '(:FIXED-SLOT-LOCATIONS ()))
(DEFCONSTANT CLOS::*<STANDARD-CLASS>-INSTANCE-SIZE* 28)
(DEFCONSTANT CLOS::*<STANDARD-CLASS>-VALID-INITIALIZATION-KEYWORDS* '(:NAME :DIRECT-SUPERCLASSES :DIRECT-SLOTS :DIRECT-DEFAULT-INITARGS :DOCUMENTATION :GENERIC-ACCESSORS :FIXED-SLOT-LOCATIONS))
(DEFCONSTANT CLOS::*<STANDARD-STABLEHASH>-HASHCODE-LOCATION* 1)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-BOA-CONSTRUCTORS-LOCATION* 23)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-COPIER-LOCATION* 24)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-INSTANCE-SIZE* 27)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-KCONSTRUCTOR-LOCATION* 22)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-NAMES-LOCATION* 21)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-PREDICATE-LOCATION* 25)
(DEFCONSTANT CLOS::*<STRUCTURE-CLASS>-PROTOTYPE-LOCATION* 26)
(DEFCONSTANT EXT::BASE-CHAR-CODE-LIMIT 1114112)
(DEFCONSTANT EXT::CHAR-BITS-LIMIT 16)
(DEFCONSTANT EXT::CHAR-CONTROL-BIT 1)
(DEFCONSTANT EXT::CHAR-FONT-LIMIT 16)
(DEFCONSTANT EXT::CHAR-HYPER-BIT 8)
(DEFCONSTANT EXT::CHAR-META-BIT 2)
(DEFCONSTANT EXT::CHAR-SUPER-BIT 4)

(DEFCONSTANT EXT::MOST-NEGATIVE-JAVA-LONG -9223372036854775808)
(DEFCONSTANT EXT::MOST-POSITIVE-JAVA-LONG 9223372036854775807)
(DEFCONSTANT SYS::*BIG-ENDIAN*  ())
(DEFCONSTANT SYS::*COMMON-LISP-USER-PACKAGE* #.(FIND-PACKAGE "COMMON-LISP-USER"))
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-BOA-CONSTRUCTORS-LOCATION* 5)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-COPIER-LOCATION* 6)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-DIRECT-SLOTS-LOCATION* 4)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-KCONSTRUCTOR-LOCATION* 2)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-PREDICATE-LOCATION* 7)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-SIZE-LOCATION* 1)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-SLOTS-LOCATION* 3)
(DEFCONSTANT SYS::*DEFSTRUCT-DESCRIPTION-TYPE-LOCATION* 0)
(DEFCONSTANT SYS::*FASL-EXTERNAL-FORMAT* "UTF-8")
(DEFCONSTANT SYS::*FASL-VERSION* 43)
(DEFCONSTANT SYS::*HTTP-PORT* 80)
(DEFCONSTANT SYS::*JMPBUF-SIZE* 25)
(DEFCONSTANT SYS::*SECLASS-DIRTY* '(T T T))
(DEFCONSTANT SYS::*SECLASS-FOLDABLE*  ())
(DEFCONSTANT SYS::*SECLASS-PURE* '(() () ()))
(DEFCONSTANT SYS::*SECLASS-READ* '(T () ()))
(DEFCONSTANT SYS::CALL-REGISTERS-LIMIT 8)
(DEFCONSTANT SYS::CHAR-INT-LIMIT 285212672)
(DEFCONSTANT SYS::DOUBLE-FLOAT-EXPONENT-BYTE '(11 . 20))
(DEFCONSTANT SYS::FORM-FEED-CHAR-CODE 12)
(DEFCONSTANT SYS::FUNTABR-INDEX 512)
(DEFCONSTANT SYS::SHORT-CODE-BASE 157)
(DEFCONSTANT SYS::SHORT-CODE-OPS #(157. 172. 197. 218. 248))
(DEFCONSTANT SYS::SHORT-CODE-OPSIZE #(15. 25. 21. 30. 8))
(DEFCONSTANT SYS::STRING-DIMENSION-LIMIT 67108864)
(DEFPARAMETER CL::*BREAK-ON-SIGNALS*  ())
(DEFPARAMETER CL::*COMPILE-FILE-PATHNAME*  ())
(DEFPARAMETER CL::*COMPILE-FILE-TRUENAME*  ())
(DEFPARAMETER CL::*COMPILE-PRINT* T)
(DEFPARAMETER CL::*COMPILE-VERBOSE* T)
(DEFPARAMETER CL::*DEBUGGER-HOOK*  ())
(DEFPARAMETER CL::*PRINT-CIRCLE* T)
(DEFPARAMETER CL::*PRINT-ESCAPE* T)
(DEFPARAMETER CL::*PRINT-GENSYM* T)
(DEFPARAMETER CL::*PRINT-LENGTH*  ())
(DEFPARAMETER CL::*PRINT-LEVEL*  ())
(DEFPARAMETER CL::*PRINT-LINES*  ())
(DEFPARAMETER CL::*PRINT-MISER-WIDTH*  ())
(DEFPARAMETER CL::*PRINT-PRETTY*  ())
(DEFPARAMETER CL::*PRINT-RADIX*  ())
(DEFPARAMETER CL::*PRINT-READABLY* T)
(DEFPARAMETER CL::*PRINT-RIGHT-MARGIN*  ())
(DEFPARAMETER CL::*READ-BASE* 10)
(DEFPARAMETER CL::*READ-DEFAULT-FLOAT-FORMAT* 'CL::SINGLE-FLOAT)
(DEFPARAMETER CL::*READ-EVAL* T)
(DEFPARAMETER CL::*READ-SUPPRESS*  ())

(DEFPARAMETER EXT::*ARGS*  ())
(DEFPARAMETER EXT::*AUTOLOAD-VERBOSE*  ())
(DEFPARAMETER EXT::*BATCH-MODE*  ())
(DEFPARAMETER EXT::*COMMAND-INDEX* 4)
(DEFPARAMETER EXT::*COMMAND-LINE-ARGUMENT-LIST*  ())
(DEFPARAMETER EXT::*DEBUG-CONDITION*  ())
(DEFPARAMETER EXT::*DEBUG-LEVEL* 0)
(DEFPARAMETER EXT::*DISASSEMBLER* "jad -a -p")
(DEFPARAMETER EXT::*ENABLE-INLINE-EXPANSION* T)
(DEFPARAMETER EXT::*INSPECTOR-HOOK*  ())
(DEFPARAMETER EXT::*KEYBOARD-INPUT*  ())
(DEFPARAMETER EXT::*LISP-HOME* #P"jar:file:/home/dmiles/logicmoo_workspace/packs_usr/armedbear_abcl/dist/abcl.jar!/org/armedbear/lisp/")
(DEFPARAMETER EXT::*LOAD-TRUENAME-FASL*  ())
(DEFPARAMETER EXT::*PRINT-STRUCTURE* T)
(DEFPARAMETER EXT::*REQUIRE-STACK-FRAME*  ())
(DEFPARAMETER EXT::*SAVED-BACKTRACE*  ())
(DEFPARAMETER EXT::*SUPPRESS-COMPILER-WARNINGS*  ())
(DEFPARAMETER EXT::*WARN-ON-REDEFINITION* T)
(DEFPARAMETER SYS::*ALL-LANGUAGES* '((I18N::ENGLISH) (I18N::DANSK) (I18N::DEUTSCH) (I18N::FRANAIS) (I18N::ESPAOL) (I18N::NEDERLANDS) (I18N::???????)))
(DEFPARAMETER SYS::*ARG-TESTS*  ())
(DEFPARAMETER SYS::*AUTOLOADING-CACHE*  ())
(DEFPARAMETER SYS::*BACKQUOTE-COUNT* 0)
(DEFPARAMETER SYS::*BACKQUOTE-OPTIMIZE-APPEND* T)
(DEFPARAMETER SYS::*BACKQUOTE-OPTIMIZE-CONS* T)
(DEFPARAMETER SYS::*BACKQUOTE-OPTIMIZE-LIST* T)
(DEFPARAMETER SYS::*BACKQUOTE-OPTIMIZE-NCONC* T)
(DEFPARAMETER SYS::*BACKQUOTE-OPTIMIZE-VECTOR* T)
(DEFPARAMETER SYS::*BREAK-COUNT* 0)
(DEFPARAMETER SYS::*CIRCULARITY-COUNTER*  ())
(DEFPARAMETER SYS::*CIRCULARITY-HASH-TABLE*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-CLASS-EXTENSION* "cls")
(DEFPARAMETER SYS::*COMPILE-FILE-DIRECTORY*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-ENVIRONMENT*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-LINENO1*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-LINENO2*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-RESOLVED-PATHNAME*  ())
(DEFPARAMETER SYS::*COMPILE-FILE-TYPE* "abcl")
(DEFPARAMETER SYS::*COMPILE-FILE-ZIP* T)
(DEFPARAMETER SYS::*COMPILED-MODULES*  ())
(DEFPARAMETER SYS::*COMPILER-UNLOCKED-PACKAGES*  ())
(DEFPARAMETER SYS::*COMPILING*  ())
(DEFPARAMETER SYS::*CONDITION-RESTARTS*  ())
(DEFPARAMETER SYS::*CONSTANT-SPECIAL-VARS*  ())
(DEFPARAMETER SYS::*COUTPUT-FILE*  ())
(DEFPARAMETER SYS::*COUTPUT-STREAM*  ())
(DEFPARAMETER SYS::*CURRENT-ERROR-DEPTH* 0)
(DEFPARAMETER SYS::*CURRENT-PRINT-LENGTH* 0)
(DEFPARAMETER SYS::*CURRENT-PRINT-LEVEL* 0)
(DEFPARAMETER SYS::*CURRENT-SOURCE-FILE*  ())
(DEFPARAMETER SYS::*CURRENT-SOURCE-LINE-1*  ())
(DEFPARAMETER SYS::*CURRENT-SOURCE-LINE-2*  ())
(DEFPARAMETER SYS::*DD-DEFAULT-SLOT-TYPE* T)
(DEFPARAMETER SYS::*DEBUG* 1)
(DEFPARAMETER SYS::*DEBUG-PRINT-FRAME-LIMIT*  ())
(DEFPARAMETER SYS::*DEPRECATED-FUNCTIONS*  ())
(DEFPARAMETER SYS::*DISASSEMBLE-USE-LIVE-PROCESS* T)
(DEFPARAMETER SYS::*DOUBLE-COLON-PACKAGE-SEPARATORS*  ())
(DEFPARAMETER SYS::*ENV-VAR*  ())
(DEFPARAMETER SYS::*EXPLAIN*  ())
(DEFPARAMETER SYS::*FASL-LOADER*  ())
(DEFPARAMETER SYS::*FASL-UNINTERNED-SYMBOLS*  ())
(DEFPARAMETER SYS::*FASOUTPUT-STREAM*  ())
(DEFPARAMETER SYS::*FFI-MODULE*  ())
(DEFPARAMETER SYS::*FORMAT-UP-AND-OUT*  ())
(DEFPARAMETER SYS::*FRAME-LIMIT-DOWN*  ())
(DEFPARAMETER SYS::*FRAME-LIMIT-UP*  ())
(DEFPARAMETER SYS::*FSET-HOOKS*  ())
(DEFPARAMETER SYS::*FUNCTIONS-WITH-ERRORS*  ())
(DEFPARAMETER SYS::*GC-STATISTICS* -1)
(DEFPARAMETER SYS::*HANDLER-CLUSTERS*  ())
(DEFPARAMETER SYS::*HOME-PACKAGE* #.(FIND-PACKAGE "COMMON-LISP-USER"))
(DEFPARAMETER SYS::*IGNORABLE-VARS*  ())
(DEFPARAMETER SYS::*IMAGE-DOC*  ())
(DEFPARAMETER SYS::*INHIBIT-FLOATING-POINT-UNDERFLOW*  ())
(DEFPARAMETER SYS::*INLINE-CONSTANTS*  ())
(DEFPARAMETER SYS::*INLINE-DEFINITIONS*  ())
(DEFPARAMETER SYS::*INLINE-FUNCTIONS*  ())
(DEFPARAMETER SYS::*INSPECT-ALL*  ())
(DEFPARAMETER SYS::*INSPECT-BREAK*  ())
(DEFPARAMETER SYS::*INSPECT-DEBUG* 0)
(DEFPARAMETER SYS::*INSPECTED-OBJECT*  ())
(DEFPARAMETER SYS::*INSPECTED-OBJECT-STACK*  ())
(DEFPARAMETER SYS::*INTERNAL-COMPILED-FILE-TYPE* "fas")
(DEFPARAMETER SYS::*INVOKE-DEBUGGER-HOOK*  ())
(DEFPARAMETER SYS::*KEY-BINDINGS*  ())
(DEFPARAMETER SYS::*KNOWN-FUNCTIONS*  ())
(DEFPARAMETER SYS::*KNOWN-SPECIAL-VARS*  ())
(DEFPARAMETER SYS::*LIBOUTPUT-STREAM*  ())
(DEFPARAMETER SYS::*LOAD-DEPTH* 0)
(DEFPARAMETER SYS::*LOAD-FORMS*  ())
(DEFPARAMETER SYS::*LOAD-INPUT-STREAM*  ())
(DEFPARAMETER SYS::*LOAD-LEVEL* 0)
(DEFPARAMETER SYS::*LOAD-STREAM*  ())
(DEFPARAMETER SYS::*LOCALIZED-RECURSION*  ())
(DEFPARAMETER SYS::*MAXIMUM-ERROR-DEPTH* 10)
(DEFPARAMETER SYS::*MODULE-PROVIDER-FUNCTIONS*  ())
(DEFPARAMETER SYS::*NOINFORM*  ())
(DEFPARAMETER SYS::*NORC*  ())
(DEFPARAMETER SYS::*NOTINLINE-CONSTANTS*  ())
(DEFPARAMETER SYS::*NOTINLINE-FUNCTIONS*  ())
(DEFPARAMETER SYS::*PACKAGE-TASKS*  ())
(DEFPARAMETER SYS::*PRIN-LINELENGTH* 145)
(DEFPARAMETER SYS::*PRINT-FASL*  ())
(DEFPARAMETER SYS::*QUIET*  ())
(DEFPARAMETER SYS::*READING-ARRAY*  ())
(DEFPARAMETER SYS::*READING-STRUCT*  ())
(DEFPARAMETER SYS::*RECURSE-COUNT-DEBUG-IO* 0)
(DEFPARAMETER SYS::*RECURSE-COUNT-ERROR-OUTPUT* 0)
(DEFPARAMETER SYS::*RECURSE-COUNT-GC-STATISTICS* 0)
(DEFPARAMETER SYS::*RECURSE-COUNT-STANDARD-OUTPUT* 0)
(DEFPARAMETER SYS::*RECURSIVE-ERROR-COUNT* 0)
(DEFPARAMETER SYS::*SAFETY* 1)
(DEFPARAMETER SYS::*SAVED-DEBUG-PACKAGE* #.(FIND-PACKAGE "COMMON-LISP-USER"))
(DEFPARAMETER SYS::*SCRIPT* T)
(DEFPARAMETER SYS::*SHARP-EQUAL-ALIST*  ())
(DEFPARAMETER SYS::*SHARP-SHARP-ALIST*  ())
(DEFPARAMETER SYS::*SOURCE*  ())
(DEFPARAMETER SYS::*SOURCE-POSITION*  ())
(DEFPARAMETER SYS::*SPACE* 1)
(DEFPARAMETER SYS::*SPEED* 1)
(DEFPARAMETER SYS::*SQUEEZE-STRING-MAX* 100)
(DEFPARAMETER SYS::*SQUEEZE-STRING-SECTION* 10)
(DEFPARAMETER SYS::*STACK-MODE* 4)
(DEFPARAMETER SYS::*STEP-LEVEL* 0)
(DEFPARAMETER SYS::*STEP-QUIT* 281474976710655)
(DEFPARAMETER SYS::*STEP-WATCH*  ())
(DEFPARAMETER SYS::*SYSTEM-LETS*  ())
(DEFPARAMETER SYS::*TOPLEVEL-DENV* '((CL::DECLARATION CL::OPTIMIZE CL::DECLARATION)))
(DEFPARAMETER SYS::*TOPLEVEL-ENVIRONMENT* #(() () () () ((CL::DECLARATION CL::OPTIMIZE CL::DECLARATION))))
(DEFPARAMETER SYS::*TRACE-LEVEL* 0)
(DEFPARAMETER SYS::*TRACED-FUNCTIONS*  ())
(DEFPARAMETER SYS::*TRACED-NAMES*  ())
(DEFPARAMETER SYS::*UNKNOWN-FREE-VARS*  ())
(DEFPARAMETER SYS::*UNKNOWN-FUNCTIONS*  ())
(DEFPARAMETER SYS::*USE-CLCS* T)
(DEFPARAMETER SYS::*USER-DECLARATION-TYPES*  ())
(DEFPARAMETER SYS::*USER-LETS*  ())
(DEFPARAMETER CL::* 'USER::PACKAGE-VALUES)
(DEFPARAMETER CL::** 'USER::MAYBE-PPRINT)
(DEFPARAMETER CL::*** 'USER::ALLPACKAGEVALUES)
(DEFPARAMETER CL::- '(USER::ALLPACKAGEVALUES))
(DEFPARAMETER CL::/ '(USER::PACKAGE-VALUES))
(DEFPARAMETER CL::// '(USER::MAYBE-PPRINT))
(DEFPARAMETER CL::/// '(USER::ALLPACKAGEVALUES))

(DEFPARAMETER SYS::*TYPE-CATEGORIES* '(CL::ARRAY CL::COMPLEX CL::CONS CL::REAL CL::CHARACTER CL::PATHNAME EXT::ENCODING CL::HASH-TABLE CL::PACKAGE CL::RANDOM-STATE CL::READTABLE CL::SYMBOL CL::BYTE EXT::SPECIAL-OPERATOR EXT::LOAD-TIME-EVAL EXT::SYMBOL-MACRO EXT::FOREIGN-POINTER FFI::FOREIGN-ADDRESS FFI::FOREIGN-VARIABLE EXT::WEAK-POINTER SYS::READ-LABEL SYS::FRAME-POINTER SYS::SYSTEM-INTERNAL CL::STRUCTURE-OBJECT CL::STANDARD-OBJECT))
(DEFPARAMETER SYS::*BACKQ-TOKENS* '(SYS::BACKQ-COMMA SYS::BACKQ-COMMA-AT SYS::BACKQ-COMMA-DOT SYS::BACKQ-LIST SYS::BACKQ-LIST* SYS::BACKQ-APPEND SYS::BACKQ-NCONC SYS::BACKQ-CONS SYS::BACKQ-VECTOR))
(DEFCONSTANT SYS::FUNCTIONS-RETURNING-STRING '(CL::STRING CL::SYMBOL-NAME CL::CHAR-NAME CL::NAMESTRING CL::ENOUGH-NAMESTRING CL::PRINC-TO-STRING CL::PRIN1-TO-STRING CL::WRITE-TO-STRING CL::WITH-OUTPUT-TO-STRING CL::GET-OUTPUT-STREAM-STRING))
(DEFPARAMETER CL::+ '(CL::DEFUN USER::PACKAGE-VALUES (USER::PS) (CL::LET ((USER::P (CL::FIND-PACKAGE USER::PS)) (USER::KWP (CL::OR (CL::FIND-PACKAGE "TMP") (CL::MAKE-PACKAGE "TMP" :USE ())))) (CL::DO-ALL-SYMBOLS (USER::SYM) (CL::WHEN (CL::AND (CL::EQ (CL::SYMBOL-PACKAGE USER::SYM) USER::P) (CL::BOUNDP USER::SYM)) (CL::LET ((CL::*PACKAGE* USER::KWP) (CL::*PRINT-ESCAPE* T) (CL::*PRINT-LINES*  ()) (CL::*PRINT-ARRAY* T) (CL::*PRINT-GENSYM* T) (CL::*PRINT-CIRCLE* T) (CL::*PRINT-READABLY* T)) (CL::FRESH-LINE) (CL::FRESH-LINE) (CL::PRINC (USER::MAYBE-PPRINT `(,(CL::IF (CL::CONSTANTP USER::SYM) :DEFCONSTANT :DEFPARAMETER) ,USER::SYM ,(CL::SYMBOL-VALUE USER::SYM))))))))))
(DEFPARAMETER CL::++ '(CL::DEFUN USER::MAYBE-PPRINT (USER::O) (CL::HANDLER-CASE (CL::WRITE-TO-STRING USER::O) (T (USER::A) (CL::LET ((CL::*PRINT-READABLY*  ())) (CL::WRITE-TO-STRING USER::O))))))
(DEFPARAMETER CL::+++ '(CL::DEFUN USER::ALLPACKAGEVALUES () (CL::DOLIST (USER::P (CL::LIST :CL :USER :SYS :EXT :CLOS)) (USER::PACKAGE-VALUES USER::P))))
(DEFPARAMETER SYS::*DEPRECATED-FUNCTIONS-ALIST* '((SOCKET::SOCKET-SERVICE-PORT #1="Use ~S instead." POSIX::SERVICE) (EXT::RENAME-DIR #1# EXT::RENAME-DIRECTORY) (EXT::MAKE-DIR #1# EXT::MAKE-DIRECTORY) (EXT::DELETE-DIR #1# EXT::DELETE-DIRECTORY) (FFI::FOREIGN-ADDRESS-NULL "The FFI now returns C NULL pointers as Lisp NIL. Use the function ~S instead." CL::NULL) (EXT::DEFINE-SETF-METHOD #1# CL::DEFINE-SETF-EXPANDER) (EXT::GET-SETF-METHOD-MULTIPLE-VALUE #1# CL::GET-SETF-EXPANSION) (EXT::SPECIAL-FORM-P #1# CL::SPECIAL-OPERATOR-P) (EXT::TYPE-EXPAND-1 #1# EXT::TYPE-EXPAND) (CL::GENTEMP "This function creates symbols that cannot be garbage-collected. Use ~S instead." CL::GENSYM) (CL::SET "This function name is anachronistic. Use ~S ~S instead." CL::SETF CL::SYMBOL-VALUE)))


;; (DEFPARAMETER SYS::*DECLARATION-TYPES* '(CL::SPECIAL CL::TYPE CL::FTYPE CL::FUNCTION CL::INLINE CL::NOTINLINE CL::IGNORE CL::OPTIMIZE CL::DYNAMIC-EXTENT CL::DECLARATION CL::ARRAY CL::ATOM CL::BASE-CHAR CL::BASE-STRING CL::BIGNUM CL::BIT CL::BIT-VECTOR CL::BOOLEAN CL::CHARACTER CL::COMPILED-FUNCTION CL::COMPLEX CL::CONS CL::DOUBLE-FLOAT CL::EXTENDED-CHAR CL::FIXNUM CL::FLOAT CL::FUNCTION CL::HASH-TABLE CL::INTEGER CL::KEYWORD CL::LIST CL::LONG-FLOAT () CL::NULL CL::NUMBER CL::PACKAGE CL::PATHNAME CL::RANDOM-STATE CL::RATIO CL::RATIONAL CL::READTABLE CL::REAL CL::SEQUENCE CL::SHORT-FLOAT CL::SIMPLE-ARRAY CL::SIMPLE-BASE-STRING CL::SIMPLE-BIT-VECTOR CL::SIMPLE-STRING CL::SIMPLE-VECTOR CL::SINGLE-FLOAT CL::STANDARD-CHAR CL::STREAM CL::STRING CS-CL::string EXT::STRING-CHAR CL::SYMBOL T CL::VECTOR CL::COMPILE SYS::SOURCE SYS::IN-DEFUN CL::IGNORABLE SYS::READ-ONLY))
;; (DEFCONSTANT SYS::FUNCTION-CODES #S(CL::HASH-TABLE :TEST EXT::STABLEHASH-EQ :WARN-IF-NEEDS-REHASH-AFTER-GC T (CL::LOGEQV . 577) (CL::LOGAND . 576) (CL::LOGXOR . 575) (CL::LOGIOR . 574) (CL::LCM . 573) (EXT::XGCD . 572) (CL::GCD . 571) (CL::/ . 570) (CL::* . 569) (CL::- . 568) (CL::+ . 567) (CL::MIN . 566) (CL::MAX . 565) (CL::>= . 564) (CL::<= . 563) (CL::> . 562) (CL::< . 561) (CL::/= . 560) (CL::= . 559) (CL::MAKE-CONCATENATED-STREAM . 558) (CL::MAKE-BROADCAST-STREAM . 557) (CL::NOTEVERY . 556) (CL::NOTANY . 555) (CL::EVERY . 554) (CL::SOME . 553) (CL::MAP-INTO . 552) (CL::MAP . 551) (CL::CONCATENATE . 550) (CLOS::%ALLOCATE-INSTANCE . 549) (CL::NCONC . 548) (CL::APPEND . 547) (CL::LIST* . 546) (CL::LIST . 545) (CLOS::CLASS-TUPLE-GETHASH . 544) (SYS::ERROR-OF-TYPE . 543) (CL::ERROR . 542) (CL::VALUES . 541) (CL::MAPCON . 540) (EXT::MAPCAP . 539) (CL::MAPCAN . 538) (CL::MAPL . 537) (CL::MAPC . 536) (CL::MAPLIST . 535) (CL::MAPCAR . 534) (CL::FUNCALL . 533) (CL::APPLY . 532) (EXT::STRING-CONCAT . 531) (CL::CHAR-NOT-LESSP . 530) (CL::CHAR-NOT-GREATERP . 529) (CL::CHAR-GREATERP . 528) (CL::CHAR-LESSP . 527) (CL::CHAR-NOT-EQUAL . 526) (CL::CHAR-EQUAL . 525) (CL::CHAR>= . 524) (CL::CHAR<= . 523) (CL::CHAR> . 522) (CL::CHAR< . 521) (CL::CHAR/= . 520) (CL::CHAR= . 519) (CL::SBIT . 518) (CL::BIT . 517) (CL::ARRAY-ROW-MAJOR-INDEX . 516) (CL::ARRAY-IN-BOUNDS-P . 515) (SYS::STORE . 514) (CL::AREF . 513) (CL::VECTOR . 512) (SYS::ENCODINGP . 511) (SYS::LOG10 . 510) (SYS::LOG2 . 509) (SYS::(SETF LONG-FLOAT-DIGITS) . 508) (EXT::LONG-FLOAT-DIGITS . 507) (EXT::EXQUO . 506) (EXT::! . 505) (CL::MAKE-RANDOM-STATE . 504) (CL::RANDOM . 503) (CL::DEPOSIT-FIELD . 502) (CL::DPB . 501) (CL::MASK-FIELD . 500) (CL::LDB-TEST . 499) (CL::LDB . 498) (CL::BYTE-POSITION . 497) (CL::BYTE-SIZE . 496) (CL::BYTE . 495) (CL::INTEGER-LENGTH . 494) (CL::LOGCOUNT . 493) (CL::ASH . 492) (CL::LOGBITP . 491) (CL::LOGTEST . 490) (CL::LOGNOT . 489) (CL::BOOLE . 488) (CL::LOGORC2 . 487) (CL::LOGORC1 . 486) (CL::LOGANDC2 . 485) (CL::LOGANDC1 . 484) (CL::LOGNOR . 483) (CL::LOGNAND . 482) (CL::IMAGPART . 481) (CL::REALPART . 480) (CL::COMPLEX . 479) (CL::INTEGER-DECODE-FLOAT . 478) (CL::FLOAT-PRECISION . 477) (CL::FLOAT-DIGITS . 476) (CL::FLOAT-SIGN . 475) (CL::FLOAT-RADIX . 474) (CL::SCALE-FLOAT . 473) (CL::DECODE-FLOAT . 472) (CL::FROUND . 471) (CL::FTRUNCATE . 470) (CL::FCEILING . 469) (CL::FFLOOR . 468) (CL::REM . 467) (CL::MOD . 466) (CL::ROUND . 465) (CL::TRUNCATE . 464) (CL::CEILING . 463) (CL::FLOOR . 462) (CL::DENOMINATOR . 461) (CL::NUMERATOR . 460) (CL::RATIONALIZE . 459) (CL::RATIONAL . 458) (CL::FLOAT . 457) (CL::ATANH . 456) (CL::ACOSH . 455) (CL::ASINH . 454) (CL::TANH . 453) (CL::COSH . 452) (CL::SINH . 451) (CL::ATAN . 450) (CL::ACOS . 449) (CL::ASIN . 448) (CL::CIS . 447) (CL::TAN . 446) (CL::COS . 445) (CL::SIN . 444) (CL::SIGNUM . 443) (CL::PHASE . 442) (CL::ABS . 441) (CL::ISQRT . 440) (CL::SQRT . 439) (CL::LOG . 438) (CL::EXPT . 437) (CL::EXP . 436) (CL::CONJUGATE . 435) (CL::1- . 434) (CL::1+ . 433) (CL::EVENP . 432) (CL::ODDP . 431) (CL::MINUSP . 430) (CL::PLUSP . 429) (CL::ZEROP . 428) (SYS::DECIMAL-STRING . 427) (CL::GENSYM . 426) (CL::KEYWORDP . 424) (CS-CL::symbol-name . 423) (CL::SYMBOL-NAME . 422) (CL::SYMBOL-PLIST . 421) (CL::SYMBOL-PACKAGE . 420) (CL::REMPROP . 419) (PUT . 418) (PUTPLIST . 417) (CL::GET-PROPERTIES . 416) (CL::GETF . 415) (CL::GET . 414) (PROCLAIM-CONSTANT . 413) (PUTD . 412) (CL::FILE-LENGTH . 411) (CL::FILE-POSITION . 410) (CL::WRITE-BYTE . 409) (CL::READ-BYTE . 408) (SYS::BUILT-IN-STREAM-CLOSE . 407) (CL::STREAM-EXTERNAL-FORMAT . 406) (SYS::BUILT-IN-STREAM-ELEMENT-TYPE . 405) (CL::OUTPUT-STREAM-P . 404) (CL::INPUT-STREAM-P . 403) (SYS::STRING-STREAM-P . 402) (SYS::MAKE-STRING-PUSH-STREAM . 401) (CL::GET-OUTPUT-STREAM-STRING . 400) (CL::MAKE-STRING-OUTPUT-STREAM . 399) (SYS::STRING-INPUT-STREAM-INDEX . 398) (CL::MAKE-STRING-INPUT-STREAM . 397) (SYS::ECHO-STREAM-P . 396) (CL::MAKE-ECHO-STREAM . 395) (SYS::TWO-WAY-STREAM-P . 394) (CL::MAKE-TWO-WAY-STREAM . 393) (SYS::CONCATENATED-STREAM-P . 392) (SYS::BROADCAST-STREAM-P . 391) (SYS::SYNONYM-STREAM-P . 390) (CL::MAKE-SYNONYM-STREAM . 389) (SYS::FILE-STREAM-P . 388) (CL::MERGE . 387) (CL::SORT . 386) (CL::SEARCH . 385) (CL::MISMATCH . 384) (CL::COUNT-IF-NOT . 383) (CL::COUNT-IF . 382) (CL::COUNT . 381) (CL::POSITION-IF-NOT . 380) (CL::POSITION-IF . 379) (CL::POSITION . 378) (CL::FIND-IF-NOT . 377) (CL::FIND-IF . 376) (CL::FIND . 375) (CL::NSUBSTITUTE-IF-NOT . 374) (CL::NSUBSTITUTE-IF . 373) (CL::NSUBSTITUTE . 372) (CL::SUBSTITUTE-IF-NOT . 371) (CL::SUBSTITUTE-IF . 370) (CL::SUBSTITUTE . 369) (CL::DELETE-DUPLICATES . 368) (CL::REMOVE-DUPLICATES . 367) (CL::DELETE-IF-NOT . 366) (CL::DELETE-IF . 365) (CL::DELETE . 364) (CL::REMOVE-IF-NOT . 363) (CL::REMOVE-IF . 362) (CL::REMOVE . 361) (CL::REPLACE . 360) (CL::FILL . 359) (CL::REDUCE . 358) (CL::MAKE-SEQUENCE . 357) (CL::NREVERSE . 356) (CL::REVERSE . 355) (CL::LENGTH . 354) (CL::COPY-SEQ . 353) (CL::SUBSEQ . 352) (SYS::(SETF ELT) . 351) (CL::ELT . 350) (SYS::SEQUENCEP . 349) (CLOS::(SETF STANDARD-INSTANCE-ACCESS) . 348) (CLOS::STANDARD-INSTANCE-ACCESS . 347) (EXT::SYMBOL-MACRO-EXPAND . 346) (SYS::SYMBOL-MACRO-P . 345) (SYS::MACRO-EXPANDER . 344) (SYS::MACROP . 343) (CLOS::SLOT-EXISTS-P . 342) (CLOS::SLOT-MAKUNBOUND . 341) (CLOS::SLOT-BOUNDP . 340) (CLOS::SET-SLOT-VALUE . 339) (CLOS::SLOT-VALUE . 338) (CLOS::STD-INSTANCE-P . 337) (CLOS::STRUCTURE-OBJECT-P . 336) (SYS::FUNCTION-MACRO-FUNCTION . 335) (SYS::MAKE-LOAD-TIME-EVAL . 334) (COPY-GENERIC-FUNCTION . 333) (SYS::MAKE-MACRO . 332) (SYS::MAKE-CLOSURE . 331) (SYS::CLOSURE-CONSTS . 330) (SYS::CLOSURE-CODEVEC . 329) (SYS::CLOSURE-NAME . 328) (STRUCTURE-TYPE-P . 327) (CL::COPY-STRUCTURE . 326) (MAKE-STRUCTURE . 325) (STRUCTURE-STORE . 324) (STRUCTURE-REF . 323) (RECORD-LENGTH . 322) (RECORD-STORE . 321) (RECORD-REF . 320) (COMPILED-FUNCTION-P . 319) (EXT::PROPER-LIST-P . 318) (CLOS::DEFINED-CLASS-P . 317) (CLOS::TYPEP-CLASS . 316) (CL::COERCE . 315) (CLOS::FIND-CLASS . 314) (CLOS::CLASS-OF . 313) (CL::TYPE-OF . 312) (CL::SIMPLE-BIT-VECTOR-P . 311) (CL::SIMPLE-STRING-P . 310) (CL::SIMPLE-VECTOR-P . 309) (CL::VECTORP . 308) (CL::BIT-VECTOR-P . 307) (SYS::SIMPLE-ARRAY-P . 306) (CL::ARRAYP . 305) (CL::PACKAGEP . 304) (CL::FUNCTIONP . 303) (CL::CHARACTERP . 302) (SYS::LOGICAL-PATHNAME-P . 301) (CL::PATHNAMEP . 300) (CL::HASH-TABLE-P . 299) (CL::READTABLEP . 298) (CL::RANDOM-STATE-P . 297) (CL::STREAMP . 296) (CL::COMPLEXP . 295) (CL::REALP . 294) (SYS::LONG-FLOAT-P . 293) (SYS::DOUBLE-FLOAT-P . 292) (SYS::SINGLE-FLOAT-P . 291) (SYS::SHORT-FLOAT-P . 290) (CL::FLOATP . 289) (CL::RATIONALP . 288) (SYS::FIXNUMP . 287) (CL::INTEGERP . 286) (CL::LISTP . 285) (SYS::CLOSUREP . 284) (CL::COMPILED-FUNCTION-P . 283) (CL::NUMBERP . 282) (CL::STRINGP . 281) (CL::SYMBOLP . 280) (CL::ATOM . 279) (CL::CONSP . 278) (CL::EQUALP . 277) (CL::EQUAL . 276) (CL::EQL . 275) (SYS::SAVEMEM . 274) (CL::FILE-AUTHOR . 273) (CL::FILE-WRITE-DATE . 272) (EXT::DELETE-DIRECTORY . 271) (EXT::MAKE-DIRECTORY . 270) (EXT::CD . 269) (CL::DIRECTORY . 268) (CL::OPEN . 267) (CL::RENAME-FILE . 266) (CL::DELETE-FILE . 265) (CL::PROBE-FILE . 264) (CL::TRUENAME . 263) (CL::NAMESTRING . 262) (CL::MAKE-PATHNAME . 261) (CL::ENOUGH-NAMESTRING . 260) (CL::MERGE-PATHNAMES . 259) (CL::HOST-NAMESTRING . 258) (CL::DIRECTORY-NAMESTRING . 257) (CL::FILE-NAMESTRING . 256) (CL::PATHNAME-VERSION . 255) (CL::PATHNAME-TYPE . 254) (CL::PATHNAME-NAME . 253) (CL::PATHNAME-DIRECTORY . 252) (CL::PATHNAME-DEVICE . 251) (CL::PATHNAME-HOST . 250) (CL::PATHNAME . 249) (CL::PARSE-NAMESTRING . 248) (EXT::RE-EXPORT . 247) (FIND-PACKAGE . 246) (SYS::MAP-ALL-SYMBOLS . 245) (SYS::MAP-EXTERNAL-SYMBOLS . 244) (SYS::MAP-SYMBOLS . 243) (CS-CL::find-all-symbols . 242) (CL::FIND-ALL-SYMBOLS . 241) (IN-PACKAGE . 240) (CS-CL::make-package . 239) (CL::MAKE-PACKAGE . 238) (CL::UNUSE-PACKAGE . 237) (CL::USE-PACKAGE . 236) (CS-CL::shadow . 235) (CL::SHADOW . 234) (CL::SHADOWING-IMPORT . 233) (CL::IMPORT . 232) (CL::UNEXPORT . 231) (CL::EXPORT . 230) (CL::UNINTERN . 229) (CS-CL::find-symbol . 228) (CL::FIND-SYMBOL . 227) (CS-CL::intern . 226) (CL::INTERN . 225) (CL::LIST-ALL-PACKAGES . 224) (CL::PACKAGE-SHADOWING-SYMBOLS . 223) (CL::PACKAGE-USED-BY-LIST . 222) (CL::PACKAGE-USE-LIST . 221) (CL::RENAME-PACKAGE . 220) (CL::PACKAGE-NICKNAMES . 219) (CL::PACKAGE-NAME . 218) (CL::FIND-PACKAGE . 217) (CL::MAKE-SYMBOL . 216) (%TIME . 215) (SLEEP . 214) (CL::GET-INTERNAL-REAL-TIME . 213) (CL::GET-INTERNAL-RUN-TIME . 212) (CL::GET-UNIVERSAL-TIME . 211) (CL::IDENTITY . 210) (CL::SOFTWARE-VERSION . 209) (CL::SOFTWARE-TYPE . 208) (CL::LISP-IMPLEMENTATION-VERSION . 207) (CL::LISP-IMPLEMENTATION-TYPE . 206) (CL::RASSOC-IF-NOT . 205) (CL::RASSOC-IF . 204) (CL::RASSOC . 203) (CL::ASSOC-IF-NOT . 202) (CL::ASSOC-IF . 201) (CL::ASSOC . 200) (CL::PAIRLIS . 199) (CL::ACONS . 198) (CL::ADJOIN . 197) (CL::TAILP . 196) (CL::MEMBER-IF-NOT . 195) (CL::MEMBER-IF . 194) (CL::MEMBER . 193) (CL::NSUBLIS . 192) (CL::SUBLIS . 191) (CL::NSUBST-IF-NOT . 190) (CL::NSUBST-IF . 189) (CL::NSUBST . 188) (CL::SUBST-IF-NOT . 187) (CL::SUBST-IF . 186) (CL::SUBST . 185) (RPLACD . 184) (CL::RPLACD . 183) (RPLACA . 182) (CL::RPLACA . 181) (CL::LDIFF . 180) (CL::NBUTLAST . 179) (CL::BUTLAST . 178) (SYS::LIST-NREVERSE . 177) (CL::NRECONC . 176) (CL::REVAPPEND . 175) (CL::COPY-TREE . 174) (SYS::MEMQ . 173) (CL::COPY-ALIST . 172) (CL::COPY-LIST . 171) (CL::MAKE-LIST . 170) (CL::LAST . 169) (CL::NTHCDR . 168) (CL::TENTH . 167) (CL::NINTH . 166) (CL::EIGHTH . 165) (CL::SEVENTH . 164) (CL::SIXTH . 163) (CL::FIFTH . 162) (CL::NTH . 161) (CL::LIST-LENGTH . 160) (CL::ENDP . 159) (CL::TREE-EQUAL . 158) (SYS::LINE-POSITION . 157) (CL::CLEAR-OUTPUT . 156) (CL::FORCE-OUTPUT . 155) (CL::FINISH-OUTPUT . 154) (EXT::ELASTIC-NEWLINE . 153) (CL::FRESH-LINE . 152) (CL::TERPRI . 151) (CL::WRITE-LINE . 150) (CL::WRITE-STRING . 149) (CL::WRITE-CHAR . 148) (CL::PRINC-TO-STRING . 147) (CL::PRIN1-TO-STRING . 146) (CL::WRITE-TO-STRING . 145) (CL::PRINC . 144) (CL::PPRINT . 143) (CL::PRINT . 142) (CL::PRIN1 . 141) (CL::WRITE . 140) (SYS::WHITESPACEP . 139) (CL::PARSE-INTEGER . 138) (CL::READ-FROM-STRING . 137) (CL::CLEAR-INPUT . 136) (CL::READ-CHAR-NO-HANG . 135) (CL::LISTEN . 134) (CL::PEEK-CHAR . 133) (CL::UNREAD-CHAR . 132) (CL::READ-CHAR . 131) (CL::READ-LINE . 130) (CL::READ-DELIMITED-LIST . 129) (CL::READ-PRESERVING-WHITESPACE . 128) (CL::READ . 127) (CL::GET-DISPATCH-MACRO-CHARACTER . 126) (CL::SET-DISPATCH-MACRO-CHARACTER . 125) (CL::MAKE-DISPATCH-MACRO-CHARACTER . 124) (CL::GET-MACRO-CHARACTER . 123) (CL::SET-MACRO-CHARACTER . 122) (CL::SET-SYNTAX-FROM-CHAR . 121) (CL::COPY-READTABLE . 120) (CL::SXHASH . 119) (CLOS::CLASS-GETHASH . 118) (SYS::HASH-TABLE-ITERATE . 117) (SYS::HASH-TABLE-ITERATOR . 116) (CL::HASH-TABLE-COUNT . 115) (CL::CLRHASH . 114) (CL::MAPHASH . 113) (CL::REMHASH . 112) (SYS::PUTHASH . 111) (CL::GETHASH . 110) (CL::MAKE-HASH-TABLE . 109) (CL::INVOKE-DEBUGGER . 108) (SYS::CHECK-FUNCTION-NAME . 107) (SYS::KEYWORD-TEST . 106) (SYS::PARSE-BODY . 105) (SYS::FUNCTION-NAME-P . 104) (SYS::FUNCTION-SIDE-EFFECT . 103) (CL::CONSTANTP . 102) (EXT::APPLYHOOK . 101) (EXT::EVALHOOK . 100) (CL::EVAL . 99) (CL::PROCLAIM . 98) (CL::MACROEXPAND-1 . 97) (CL::MACROEXPAND . 96) (CL::MACRO-FUNCTION . 95) (SYS::UNWIND-TO-DRIVER . 94) (SYS::DRIVER . 93) (CL::FMAKUNBOUND . 92) (CL::MAKUNBOUND . 91) (SYS::SET-SYMBOL-VALUE . 90) (CL::SPECIAL-OPERATOR-P . 89) (CL::FBOUNDP . 88) (CL::BOUNDP . 87) (CL::FDEFINITION . 86) (CL::SYMBOL-VALUE . 85) (EXT::SUBSTRING . 84) (CL::NAME-CHAR . 83) (CS-CL::string . 82) (CL::STRING . 81) (CL::STRING-CAPITALIZE . 80) (CL::NSTRING-CAPITALIZE . 79) (CL::STRING-DOWNCASE . 78) (CL::NSTRING-DOWNCASE . 77) (CL::STRING-UPCASE . 76) (CL::NSTRING-UPCASE . 75) (SYS::STRING-BOTH-TRIM . 74) (CL::MAKE-STRING . 73) (SYS::SEARCH-STRING-EQUAL . 72) (SYS::SEARCH-STRING= . 71) (CL::STRING-NOT-LESSP . 70) (CL::STRING-NOT-GREATERP . 69) (CL::STRING-GREATERP . 68) (CL::STRING-LESSP . 67) (CL::STRING-NOT-EQUAL . 66) (CL::STRING-EQUAL . 65) (CS-CL::string>= . 64) (CL::STRING>= . 63) (CS-CL::string<= . 62) (CL::STRING<= . 61) (CS-CL::string> . 60) (CL::STRING> . 59) (CS-CL::string< . 58) (CL::STRING< . 57) (CS-CL::string/= . 56) (CL::STRING/= . 55) (CS-CL::string= . 54) (CL::STRING= . 53) (SYS::STORE-SCHAR . 52) (SYS::STORE-CHAR . 51) (CL::SCHAR . 50) (CL::CHAR . 49) (CL::CHAR-NAME . 48) (EXT::INT-CHAR . 47) (CL::CHAR-INT . 46) (CL::DIGIT-CHAR . 45) (CL::CHAR-DOWNCASE . 44) (CL::CHAR-UPCASE . 43) (CL::CHARACTER . 42) (CL::CODE-CHAR . 41) (CL::CHAR-CODE . 40) (CL::ALPHANUMERICP . 39) (CL::DIGIT-CHAR-P . 38) (CL::BOTH-CASE-P . 37) (CL::LOWER-CASE-P . 36) (CL::UPPER-CASE-P . 35) (CL::ALPHA-CHAR-P . 34) (EXT::STRING-CHAR-P . 33) (CL::GRAPHIC-CHAR-P . 32) (CL::STANDARD-CHAR-P . 31) (CL::ADJUST-ARRAY . 30) (CL::MAKE-ARRAY . 29) (CL::VECTOR-PUSH-EXTEND . 28) (CL::VECTOR-POP . 27) (CL::VECTOR-PUSH . 26) (SYS::SET-FILL-POINTER . 25) (CL::FILL-POINTER . 24) (CL::ARRAY-HAS-FILL-POINTER-P . 23) (CL::BIT-NOT . 22) (CL::BIT-ORC2 . 21) (CL::BIT-ORC1 . 20) (CL::BIT-ANDC2 . 19) (CL::BIT-ANDC1 . 18) (CL::BIT-NOR . 17) (CL::BIT-NAND . 16) (CL::BIT-EQV . 15) (CL::BIT-XOR . 14) (CL::BIT-IOR . 13) (CL::BIT-AND . 12) (CL::ADJUSTABLE-ARRAY-P . 11) (CL::ARRAY-TOTAL-SIZE . 10) (CL::ARRAY-DIMENSIONS . 9) (CL::ARRAY-DIMENSION . 8) (CL::ARRAY-RANK . 7) (CL::ARRAY-ELEMENT-TYPE . 6) (SYS::ROW-MAJOR-STORE . 5) (CL::ROW-MAJOR-AREF . 4) (COPY-SIMPLE-VECTOR . 3) (EXT::SPECIAL-VARIABLE-P . 2) (SYS::SUBR-INFO . 1) (FUNTABREF . 0)))



